# If you remove the mercurial-nested package without purging it, this conffile
# will be kept and mercurial will try to load the (removed) extension and emit
# a warning in case the extension is enabled.
#
# Two fixes are possible in this case:
# 1: purging the mercurial-nested package (e.g. "apt-get remove --purge mercurial-nested")
# 2: commenting the line requesting the extension below

# To enable the hgnested extension system wide, uncomment the following lines
# [extensions]
# hgnested =
